macro_rules! crate_patch {
() => { ... };
}Expand description
Gets the patch version of the crate as defined in your Cargo.toml.
Will be &str
macro_rules! crate_patch {
() => { ... };
}Gets the patch version of the crate as defined in your Cargo.toml.
Will be &str